.. _Python: https://www.python.org/
.. _webassets: https://github.com/miracle2k/webassets
.. _Jinja2: https://jinja.palletsprojects.com/
.. _Babel: http://babel.pocoo.org/
.. _click: https://click.palletsprojects.com/
.. _watchdog: https://python-watchdog.readthedocs.io
.. _rcssmin: https://pypi.org/project/rcssmin/
.. _jsmin: https://pypi.org/project/jsmin/
.. _CherryPy: https://docs.cherrypy.dev/


Optimus
=======

Optimus is a static site builder, it produces HTML from templates (through `Jinja2`_)
with assets management (through `webassets`_) and supports i18n for translations
(through `Babel`_).


Dependencies
************

* `Python`_>=3.8;
* `Jinja2`_;
* `webassets`_;
* `Babel`_;
* `click`_;
* `watchdog`_;
* `rcssmin`_;
* `jsmin`_;
* `CherryPy`_;


Links
*****

* Read the documentation on `Read the docs <https://optimus.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/Optimus>`_;
* Clone it on its `Github repository <https://github.com/sveetch/Optimus>`_;


Credits
*******

Logo vector and icon by `SVG Repo <https://www.svgrepo.com>`_.
